@@ -8,7 +8,7 @@ readonly name="GoogleTest"
 readonly ownership="Google Test Upstream <robot@adios2>"
 readonly subtree="thirdparty/GTest/googletest"
 readonly repo="https://github.com/google/googletest.git"
-readonly tag="main"
+readonly tag="v1.14.0"
 readonly shortlog="true"
 readonly paths="
 "
